BorderRadiusBuilder class

Internal builder class to support chaining syntax like 12.tLeftRad.bRightRad

Available extensions

Constructors

BorderRadiusBuilder()

Properties

bLeftRad BorderRadiusBuilder
no setter
bottomRad BorderRadiusBuilder
no setter
bRightRad BorderRadiusBuilder
no setter
geometry BorderRadiusGeometry

Available on BorderRadiusBuilder, provided by the BorderRadiusBuilderConversion extension

Allows implicit conversion to BorderRadiusGeometry
no setter
hashCode int
The hash code for this object.
no setterinherited
leftRad BorderRadiusBuilder
no setter
radius BorderRadius

Available on BorderRadiusBuilder, provided by the BorderRadiusBuilderConversion extension

Converts builder to BorderRadius
no setter
rightRad BorderRadiusBuilder
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tLeftRad BorderRadiusBuilder
Chainable getters with "Rad" suffix
no setter
topRad BorderRadiusBuilder
Convenience getters for multiple corners with "Rad" suffix
no setter
tRightRad BorderRadiusBuilder
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBorderRadius() BorderRadius
Implicit conversion to BorderRadius
toString() String
A string representation of this object.
inherited
withBottomLeft(double value) BorderRadiusBuilder
Adds bottomLeft radius and returns builder for chaining
withBottomRight(double value) BorderRadiusBuilder
Adds bottomRight radius and returns builder for chaining
withTopLeft(double value) BorderRadiusBuilder
Adds topLeft radius and returns builder for chaining
withTopRight(double value) BorderRadiusBuilder
Adds topRight radius and returns builder for chaining

Operators

operator ==(Object other) bool
The equality operator.
inherited